This is an automated email from the ASF dual-hosted git repository.

xiaoxiang pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-nuttx.git


The following commit(s) were added to refs/heads/master by this push:
     new 41c3b42  change /dev/syslog & /dev/ramlog for unix standard
41c3b42 is described below

commit 41c3b42468adeda7c3b52e1ac6cfa7f0c75fffe9
Author: anjiahao <[email protected]>
AuthorDate: Tue Nov 23 15:55:46 2021 +0800

    change /dev/syslog & /dev/ramlog for unix standard
    
    Signed-off-by: anjiahao <[email protected]>
---
 drivers/syslog/Kconfig          | 4 ++--
 drivers/syslog/syslog.h         | 2 +-
 drivers/syslog/syslog_chardev.c | 4 ++--
 include/nuttx/syslog/ramlog.h   | 2 +-
 4 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/drivers/syslog/Kconfig b/drivers/syslog/Kconfig
index 66cfd5b..e8f68e8 100644
--- a/drivers/syslog/Kconfig
+++ b/drivers/syslog/Kconfig
@@ -330,7 +330,7 @@ config SYSLOG_DEVPATH
        depends on SYSLOG_CHAR
        ---help---
                The full path to the system logging device.  For the RAMLOG 
SYSLOG device,
-               this is normally "/dev/ramlog".  For character SYSLOG devices, 
it should be
+               this is normally "/dev/kmsg".  For character SYSLOG devices, it 
should be
                some other existing character device (or file) supported by the 
configuration
                (such as "/dev/ttyS1")/
 
@@ -338,7 +338,7 @@ config SYSLOG_CHARDEV
        bool "SYSLOG character device"
        default n
        ---help---
-               Enables support for a simple character driver at /dev/syslog 
whose
+               Enables support for a simple character driver at /dev/log whose
                write() method will transfer data to the SYSLOG device.  This 
can be
                useful if, for example, you want to redirect the output of a 
program
                to the SYSLOG.
diff --git a/drivers/syslog/syslog.h b/drivers/syslog/syslog.h
index a1e7e28..5e32dd2 100644
--- a/drivers/syslog/syslog.h
+++ b/drivers/syslog/syslog.h
@@ -163,7 +163,7 @@ FAR struct syslog_channel_s *syslog_console_channel(void);
  * Name: syslog_register
  *
  * Description:
- *   Register a simple character driver at /dev/syslog whose write() method
+ *   Register a simple character driver at /dev/log whose write() method
  *   will transfer data to the SYSLOG device.  This can be useful if, for
  *   example, you want to redirect the output of a program to the SYSLOG.
  *
diff --git a/include/nuttx/syslog/ramlog.h b/include/nuttx/syslog/ramlog.h
index a71f02e..1efab7c 100644
--- a/include/nuttx/syslog/ramlog.h
+++ b/include/nuttx/syslog/ramlog.h
@@ -67,7 +67,7 @@
  */
 
 #if defined(CONFIG_RAMLOG_SYSLOG) && !defined(CONFIG_SYSLOG_DEVPATH)
-#  define CONFIG_SYSLOG_DEVPATH "/dev/ramlog"
+#  define CONFIG_SYSLOG_DEVPATH "/dev/kmsg"
 #endif
 
 #ifndef CONFIG_RAMLOG_NPOLLWAITERS

Reply via email to
diff --git a/drivers/syslog/syslog_chardev.c b/drivers/syslog/syslog_chardev.c
index 16abf8f..08c5503 100644
--- a/drivers/syslog/syslog_chardev.c
+++ b/drivers/syslog/syslog_chardev.c
@@ -85,7 +85,7 @@ static ssize_t syslog_chardev_write(FAR struct file *filep,
  * Name: syslog_register
  *
  * Description:
  *   Register a simple character driver at /dev/syslog whose write() method
  *   will transfer data to the SYSLOG device.  This can be useful if, for
  *   example, you want to redirect the output of a program to the SYSLOG.
  *
@@ -97,7 +97,7 @@ static ssize_t syslog_chardev_write(FAR struct file *filep,
 
 void syslog_register(void)
 {
-  register_driver("/dev/syslog", &syslog_fops, 0222, NULL);
+  register_driver("/dev/log", &syslog_fops, 0222, NULL);
 }
 
 #endif /* CONFIG_SYSLOG_CHARDEV */
@@ -85,7 +85,7 @@ static ssize_t syslog_chardev_write(FAR struct file *filep,
  *
  * Description:
- *   Register a simple character driver at /dev/syslog whose write() method
+ *   Register a simple character driver at /dev/log whose write() method
  *   will transfer data to the SYSLOG device.  This can be useful if, for
  *   example, you want to redirect the output of a program to the SYSLOG.